from famegui import app

if __name__ == "__main__":
    app.run()
